==> random_profile-0.0.8.tar.gz: random_profile-0.0.8/README.md <==
# Random Profile Generator

## Introduction

RandomProfile is a powerful and simple tool to generate fake data. You can use it to mock classes, populate databases and and much more. You can check the full documentation here.

```python
pip install random-profile
```

## Documentation

```python
from random_profile as RandomProfile
rp = RandomProfile(num=5)
'''

num = Total No. of Name You Want To Print
default is 1
change the num value according to your needs.

'''
# For First Name
rp.first_name()

# For First Name
rp.full_name()

# For First Name
rp.full_profile()
```

## Installation

- This is A python 3 Package.
- Install python 3.0+ or Anaconda 3.0+

```python
Pip install random-profile   #on python
conda install random-profile # on anacoda
```

## Usage

random-profile module is a random profile generator for many usages ex- fake dataset,youtube videos, content creation, personal projects.

## Support

Contributors for the Project
[CodePerfectPLus](https://github.com/codePerfectPlus)
...

## Roadmap

what's new in future update

- More Random data will be added to package.
- variety of Random-Data will increase.

## Contributing

Before submitting a bug, please do the following:

Perform basic troubleshooting steps:

- Make sure you are on the latest version. If you are not on the most recent version, your problem may have been solved already! Upgrading is always the best first step.
- Try older versions. If you are already on the latest release, try rolling back a few minor versions (e.g. if on 1.7, try 1.5 or 1.6) and see if the problem goes away. This will help the devs narrow down when the problem first arose in the commit log.
- Try switching up dependency versions. If the software in question has dependencies (other libraries, etc) try upgrading/downgrading those as well.

## Authors and acknowledgment

Show your appreciation to those who have contributed to the project.

## License

For open source projects,Under MIT License.

## Project status

## Author

- Module : random-profile
- Author  : CodePerfectPlus
- Language : Python
- Github : <https://github.com/codePerfectPlus>
- Website : <http://codeperfectplus.github.io/>

==> random_profile-0.1.0.tar.gz: random_profile-0.1.0/README.md <==
# Random Profile Generator

## Introduction

RandomProfile is a powerful and simple tool to generate fake data. You can use it to mock classes, populate databases and and much more. You can check the full documentation here.

```python
pip install random-profile
```

## Documentation

```python
from random_profile import RandomProfile
rp = RandomProfile(num=5)
'''

num = Total No. of Name You Want To Print
default is 1
change the num value according to your needs.

'''
# For First Name
rp.first_name()

# For First Name
rp.full_name()

# For First Name
rp.full_profile()
```

## Installation

- This is A python 3 Package.
- Install python 3.0+ or Anaconda 3.0+

```python
Pip install random-profile   #on python
conda install random-profile # on anacoda
```

## Usage

random-profile module is a random profile generator for many usages ex- fake dataset,youtube videos, content creation, personal projects.

## Support

Contributors for the Project
[CodePerfectPLus](https://github.com/codePerfectPlus)
...

## Roadmap

what's new in future update

- More Random data will be added to package.
- variety of Random-Data will increase.

## Contributing

Before submitting a bug, please do the following:

Perform basic troubleshooting steps:

- Make sure you are on the latest version. If you are not on the most recent version, your problem may have been solved already! Upgrading is always the best first step.
- Try older versions. If you are already on the latest release, try rolling back a few minor versions (e.g. if on 1.7, try 1.5 or 1.6) and see if the problem goes away. This will help the devs narrow down when the problem first arose in the commit log.
- Try switching up dependency versions. If the software in question has dependencies (other libraries, etc) try upgrading/downgrading those as well.

## Authors and acknowledgment

Show your appreciation to those who have contributed to the project.

## License

For open source projects,Under MIT License.

## Project status

## Author

- Module : random-profile
- Author  : CodePerfectPlus
- Language : Python
- Github : <https://github.com/codePerfectPlus>
- Website : <http://codeperfectplus.github.io/>
